@@ -789,7 +789,8 @@ class mdx:
                         sf = "![alt text](../pics/%s '%s')" % (a[1], a[1])
                     self.FIG += 1
                     figno = "%d.%d" % (self.Page, self.FIG)
-                    sf += "\n\n<i>Figure %s. %s</i>\n\n" % (figno, arg2)
+                    if arg2!="NONE":
+                        sf += "\n\n<i>Figure %s. %s</i>\n\n" % (figno, arg2)
                 elif fnum == 4 or fnum == 42:  # image pop up (pics folder)
                     if fnum == 4:
                         sf = imgref("pics/%s" % a[1], a[2])
@@ -1326,4 +1327,4 @@ def sapp(p, s):
         i += 1
 
 def xtver():
-    return "ver 1.0.2 10:06 am 15 July 2021"
\ No newline at end of file
+    return "ver 1.0.3 3 pm 20 July 2021"
\ No newline at end of file
